@@ -237,8 +237,8 @@ class ConjIdMap(object):
         as there are 4 priority levels (see rules.flow_priority_offset)
         and 2 conjunction IDs are needed per priority.
         """
-        if direction not in [firewall.EGRESS_DIRECTION,
-                             firewall.INGRESS_DIRECTION]:
+        if direction not in [lib_const.EGRESS_DIRECTION,
+                             lib_const.INGRESS_DIRECTION]:
             raise ValueError("Invalid direction '%s'" % direction)
         if ethertype not in [lib_const.IPv4, lib_const.IPv6]:
             raise ValueError("Invalid ethertype '%s'" % ethertype)
@@ -364,7 +364,7 @@ class ConjIPFlowManager(object):
             for sg_conj_id_map in vlan_conj_id_map.values():
                 for remote_sg_id, unused in unused_dict.items():
                     if (remote_sg_id in sg_conj_id_map and
-                        sg_conj_id_map[remote_sg_id] & unused):
+                            sg_conj_id_map[remote_sg_id] & unused):
                         sg_conj_id_map[remote_sg_id] -= unused
                         if not sg_conj_id_map[remote_sg_id]:
                             del sg_conj_id_map[remote_sg_id]
@@ -709,8 +709,7 @@ class OVSFirewallDriver(firewall.FirewallDriver):
                 dl_type=constants.ETHERTYPE_IPV6,
                 nw_proto=lib_const.PROTO_NUM_IPV6_ICMP,
                 icmp_type=icmp_type,
-                actions='resubmit(,%d)' % (
-                    ovs_consts.ACCEPTED_EGRESS_TRAFFIC_TABLE)
+                actions='normal'
             )
 
     def _initialize_egress_no_port_security(self, port_id):
@@ -744,9 +743,7 @@ class OVSFirewallDriver(firewall.FirewallDriver):
             table=ovs_consts.ACCEPT_OR_INGRESS_TABLE,
             priority=80,
             reg_port=ovs_port.ofport,
-            actions='resubmit(,%d)' % (
-                ovs_consts.ACCEPTED_EGRESS_TRAFFIC_TABLE)
-
+            actions='normal'
         )
 
     def _remove_egress_no_port_security(self, port_id):
@@ -781,8 +778,7 @@ class OVSFirewallDriver(firewall.FirewallDriver):
                 dl_src=mac_addr,
                 dl_type=constants.ETHERTYPE_ARP,
                 arp_spa=ip_addr,
-                actions='resubmit(,%d)' % (
-                    ovs_consts.ACCEPTED_EGRESS_TRAFFIC_TABLE)
+                actions='normal'
             )
             self._add_flow(
                 table=ovs_consts.BASE_EGRESS_TABLE,
@@ -897,8 +893,7 @@ class OVSFirewallDriver(firewall.FirewallDriver):
             table=ovs_consts.ACCEPT_OR_INGRESS_TABLE,
             priority=80,
             reg_port=port.ofport,
-            actions='resubmit(,%d)' % (
-                ovs_consts.ACCEPTED_EGRESS_TRAFFIC_TABLE)
+            actions='normal'
         )
 
     def _initialize_tracked_egress(self, port):
@@ -929,8 +924,7 @@ class OVSFirewallDriver(firewall.FirewallDriver):
                 ct_mark=ovsfw_consts.CT_MARK_NORMAL,
                 reg_port=port.ofport,
                 ct_zone=port.vlan_tag,
-                actions='resubmit(,%d)' % (
-                    ovs_consts.ACCEPTED_EGRESS_TRAFFIC_TABLE)
+                actions='normal'
             )
         self._add_flow(
             table=ovs_consts.RULES_EGRESS_TABLE,
@@ -961,9 +955,7 @@ class OVSFirewallDriver(firewall.FirewallDriver):
                 dl_type=constants.ETHERTYPE_IPV6,
                 nw_proto=lib_const.PROTO_NUM_IPV6_ICMP,
                 icmp_type=icmp_type,
-                actions='output:{:d},resubmit(,{:d})'.format(
-                    port.ofport,
-                    ovs_consts.ACCEPTED_INGRESS_TRAFFIC_TABLE),
+                actions='output:{:d}'.format(port.ofport)
             )
 
     def _initialize_ingress(self, port):
@@ -973,9 +965,7 @@ class OVSFirewallDriver(firewall.FirewallDriver):
             priority=100,
             dl_type=constants.ETHERTYPE_ARP,
             reg_port=port.ofport,
-            actions='output:{:d},resubmit(,{:d})'.format(
-                port.ofport,
-                ovs_consts.ACCEPTED_INGRESS_TRAFFIC_TABLE),
+            actions='output:{:d}'.format(port.ofport)
         )
         self._initialize_ingress_ipv6_icmp(port)
 
@@ -991,9 +981,7 @@ class OVSFirewallDriver(firewall.FirewallDriver):
                 nw_proto=lib_const.PROTO_NUM_UDP,
                 tp_src=src_port,
                 tp_dst=dst_port,
-                actions='output:{:d},resubmit(,{:d})'.format(
-                    port.ofport,
-                    ovs_consts.ACCEPTED_INGRESS_TRAFFIC_TABLE),
+                actions='output:{:d}'.format(port.ofport)
             )
 
         # Track untracked
@@ -1043,9 +1031,7 @@ class OVSFirewallDriver(firewall.FirewallDriver):
                 ct_state=state,
                 ct_mark=ovsfw_consts.CT_MARK_NORMAL,
                 ct_zone=port.vlan_tag,
-                actions='output:{:d},resubmit(,{:d})'.format(
-                    port.ofport,
-                    ovs_consts.ACCEPTED_INGRESS_TRAFFIC_TABLE)
+                actions='output:{:d}'.format(port.ofport)
             )
         self._add_flow(
             table=ovs_consts.RULES_INGRESS_TABLE,
